use warnings;
use strict;

use Pod::Usage::CommandLine;

BEGIN { our $VERSION = '0.01'; }

print "Hello World\n";

__END__

=head1 NAME

sample - sample program to illustrate Pod::Usage::CommandLine

=head1 SYNOPSIS

 sample [--help|-h|-q] [--man|-m] [--version]

=head1 DESCRIPTION

Sample program to illustrate Pod::Usage::CommandLine options.

=head1 COPYRIGHT AND LICENSE

Public Domain

=head1 AUTHOR

Curt Tilmes

=cut
